"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.initialState = void 0;
const actions_1 = require("./actions");
exports.initialState = {
    answers: [],
    answerInputs: {},
    prevAnswerInputs: {},
    isQuizCompleted: false,
};
function answerInputReducer(state, action) {
    return Object.assign(Object.assign({}, state), { [String(action.payload.questionId)]: {
            type: action.type,
            value: action.payload.input,
        } });
}
function quizLocalReducer(state, action) {
    var _a;
    switch (action.type) {
        case actions_1.QuestionTypes.OpenText:
            return Object.assign(Object.assign({}, state), { answerInputs: answerInputReducer(state.answerInputs, action), isQuizCompleted: false });
        case actions_1.QuestionTypes.Cover:
            return Object.assign(Object.assign({}, state), { answerInputs: answerInputReducer(state.answerInputs, action), isQuizCompleted: false });
        case actions_1.QuestionTypes.SingleSelect:
            return Object.assign(Object.assign({}, state), { answerInputs: answerInputReducer(state.answerInputs, action), isQuizCompleted: false });
        case actions_1.QuestionTypes.MultipleSelect:
            return Object.assign(Object.assign({}, state), { answerInputs: answerInputReducer(state.answerInputs, action), isQuizCompleted: false });
        case actions_1.QuestionTypes.Next: {
            const { answers, answerInputs } = state;
            const newAnswers = [...answers];
            const lastAnswerInputIndex = answers.length;
            const currentAnswerInput = (_a = Object.values(state.answerInputs)) === null || _a === void 0 ? void 0 : _a[lastAnswerInputIndex];
            switch (currentAnswerInput.type) {
                case actions_1.QuestionTypes.OpenText:
                    newAnswers.push(['true']);
                    break;
                case actions_1.QuestionTypes.Cover:
                    newAnswers.push(['seen']);
                    break;
                case actions_1.QuestionTypes.SingleSelect:
                case actions_1.QuestionTypes.MultipleSelect:
                    newAnswers.push(currentAnswerInput.value.map((answer) => answer.id));
                    break;
                default:
                    newAnswers.push([]);
            }
            return Object.assign(Object.assign({}, state), { 
                // We now commit current answers to prevAnswerInputs
                prevAnswerInputs: answerInputs, answers: newAnswers, isQuizCompleted: false });
        }
        case actions_1.QuestionTypes.Skip: {
            const { answers, answerInputs } = state;
            const newAnswers = [...answers];
            const lastAnswerInputIndex = answers.length;
            const currentAnswerInput = Object.values(state.answerInputs)[lastAnswerInputIndex];
            switch (currentAnswerInput.type) {
                case actions_1.QuestionTypes.OpenText:
                    newAnswers.push(['false']);
                    break;
                case actions_1.QuestionTypes.Cover:
                    newAnswers.push(['seen']);
                    break;
                case actions_1.QuestionTypes.SingleSelect:
                case actions_1.QuestionTypes.MultipleSelect:
                default:
                    newAnswers.push([]);
            }
            return Object.assign(Object.assign({}, state), { 
                // We now commit current answers to prevAnswerInputs
                prevAnswerInputs: answerInputs, answers: newAnswers, isQuizCompleted: false });
        }
        case actions_1.QuestionTypes.Back: {
            const prevAnswerInputs = Object.assign({}, state.prevAnswerInputs);
            return Object.assign(Object.assign({}, state), { answerInputs: prevAnswerInputs, answers: [...state.answers.slice(0, -1)], isQuizCompleted: false });
        }
        case actions_1.QuestionTypes.Reset:
            return Object.assign({}, exports.initialState);
        case actions_1.QuestionTypes.Hydrate:
            return Object.assign(Object.assign({}, state), action.payload);
        case actions_1.QuestionTypes.Complete:
            return Object.assign(Object.assign({}, state), { isQuizCompleted: true });
        default:
            return state;
    }
}
exports.default = quizLocalReducer;
