import React, { useContext } from 'react';
import ResultCtaButton from '../ResultCtaButton/ResultCtaButton';
import ResultFavoritesButton from '../ResultFavoritesButton/ResultFavoritesButton';
import QuizContext from '../CioQuiz/context';
export default function ResultCard(props) {
    const { result, salePriceKey, regularPriceKey, resultPosition, ratingCountKey, ratingScoreKey, renderResultCardPriceDetails, } = props;
    const { customAddToFavoritesCallback, customClickItemCallback, getQuizResultButtonProps, getQuizResultLinkProps, } = useContext(QuizContext);
    const salePrice = salePriceKey && result?.data?.[salePriceKey];
    const regularPrice = regularPriceKey && result?.data?.[regularPriceKey];
    const ratingCount = ratingCountKey && result?.data?.[ratingCountKey];
    const ratingScore = ratingScoreKey && result?.data?.[ratingScoreKey];
    const resultCardContent = () => (React.createElement(React.Fragment, null,
        React.createElement("div", { className: 'cio-result-card-image' },
            React.createElement("img", { src: result.data?.image_url, alt: 'product' })),
        React.createElement("div", { className: 'cio-result-card-text' },
            React.createElement("p", { className: 'cio-result-card-title' }, result.value),
            React.createElement("div", { className: 'cio-result-card-details' },
                React.createElement("div", { className: 'cio-result-card-rating' },
                    ratingScore && (React.createElement("span", { className: 'cio-result-card-rating-score' },
                        Array(Number(ratingScore)).fill('★'),
                        Array(5 - Number(ratingScore)).fill('☆'))),
                    ratingCount && React.createElement("span", { className: 'cio-result-card-rating-count' },
                        "(",
                        ratingCount,
                        ")")),
                renderResultCardPriceDetails ? (renderResultCardPriceDetails(result)) : (React.createElement("div", { className: 'cio-result-card-prices' },
                    salePrice && React.createElement("span", { className: 'cio-result-card-sale-price' },
                        "$",
                        salePrice),
                    regularPrice && (React.createElement("span", { className: `cio-result-card-regular-price${salePrice ? '--strike-through' : ''}` },
                        "$",
                        regularPrice))))))));
    const resultCardContentWithoutLink = () => getQuizResultButtonProps && (React.createElement("div", { ...getQuizResultButtonProps({ result, position: resultPosition, type: 'button' }) }, resultCardContent()));
    const resultCardContentWithLink = () => getQuizResultLinkProps && (React.createElement("a", { className: 'cio-result-card-anchor', rel: 'noreferrer', target: '_blank', ...getQuizResultLinkProps({ result, position: resultPosition, type: 'link' }) }, resultCardContent()));
    return (React.createElement("div", { className: 'cio-result-card' },
        customAddToFavoritesCallback && (React.createElement(ResultFavoritesButton, { item: result, price: salePrice || regularPrice })),
        !customClickItemCallback ? resultCardContentWithLink() : resultCardContentWithoutLink(),
        React.createElement(ResultCtaButton, { item: result, price: salePrice || regularPrice })));
}
